**Example 1: 示例**



Input: 

```
tccli cwp ModifyOrderAttribute --cli-unfold-argument  \
    --LicenseType 1 \
    --ResourceId resource_id \
    --AttrName alias \
    --AttrValue 资源别名
```

Output: 
```
{
    "Response": {
        "RequestId": "d09cfcae-fab2-4cb7-a41e-5fd4c12d69f4"
    }
}
```

